@@ -2,6 +2,7 @@
 #include "protocols/mceprotocol.h"
 #include "protocols/necprotocol.h"
 #include "protocols/nokia32protocol.h"
+#include "protocols/aiwaprotocol.h"
 
 ADBSTB1::ADBSTB1(
   unsigned int index)
@@ -233,3 +234,65 @@ void ADBSTB4::populateProtocol(
   addKey("Enter", Enter_Key, 0xDB, 8);
   addKey("exit", Exit_Key, 0xE0, 8);
 }
+
+
+ADBSTB5::ADBSTB5(
+  unsigned int index)
+  : PIRKeysetMetaData(
+      "TV Receiver Keyset 5",
+      ADB_Make,
+      index)
+{
+}
+
+
+void ADBSTB5::populateProtocol(
+  QObject *guiObject)
+{
+  if (threadableProtocol)
+  {
+    // Keyset already populated.
+    return;
+  }
+
+  threadableProtocol = new AiwaProtocol(guiObject, index);
+
+  setPreData(0x0008, 13);
+
+  addKey("0", Zero_Key, 0x00, 8);
+  addKey("1", One_Key, 0x01, 8);
+  addKey("2", Two_Key, 0x02, 8);
+  addKey("3", Three_Key, 0x03, 8);
+  addKey("4", Four_Key, 0x04, 8);
+  addKey("5", Five_Key, 0x05, 8);
+  addKey("6", Six_Key, 0x06, 8);
+  addKey("7", Seven_Key, 0x07, 8);
+  addKey("8", Eight_Key, 0x08, 8);
+  addKey("9", Nine_Key, 0x09, 8);
+  addKey("Menu", Menu_Key, 0x0A, 8);
+  addKey("Guide", Guide_Key, 0x0B, 8);
+  addKey("Power", Power_Key, 0x0C, 8);
+  addKey("Format 16:9", AspectRatio_Key, 0x0D, 8);
+  addKey("Info/Display", Info_Key, 0x0D, 8);
+  addKey("Stop", Stop_Key, 0x0D, 8);
+  addKey("CH+", ChannelUp_Key, 0x0E, 8);
+  addKey("CH-", ChannelDown_Key, 0xF, 8);
+  addKey("Volume +", VolumeUp_Key, 0x10, 8);
+  addKey("Volume -", VolumeDown_Key, 0x11, 8);
+  addKey("Arrow_Right", Right_Key, 0x12, 8);
+  addKey("FFWD", FastForward_Key, 0x13, 8);
+  addKey("EXIT", Exit_Key, 0x14, 8);
+  addKey("Arrow_Left", Left_Key, 0x15, 8);
+  addKey("OK/Select", Select_Key, 0x16, 8);
+  addKey("Subtitle", Captions_Key, 0x18, 8);
+  addKey("Mute", Mute_Key, 0x1A, 8);
+  addKey("Input/Source", Input_Key, 0x1B, 8);
+  addKey("Arrow_Down", Down_Key, 0x1C, 8);
+  addKey("Arrow_Up", Up_Key, 0x1D, 8);
+  addKey("Play", Play_Key, 0x1E, 8);
+  addKey("Audio", Audio_Key, 0x1F, 8);
+  addKey("Red", Red_Key, 0x20, 8);
+  addKey("Green", Green_Key, 0x21, 8);
+  addKey("Yellow", Yellow_Key, 0x22, 8);
+  addKey("Blue", Blue_Key, 0x23, 8);
+}
