@@ -25,6 +25,7 @@ enum PIRMakeName{
   Compro_Make,
   Creative_Make,
   Crown_Make,
+  CrownMustang_Make,
   Daewoo_Make,
   Dell_Make,
   Denon_Make,
@@ -48,6 +49,7 @@ enum PIRMakeName{
   Goodmans_Make,
   Grundig_Make,
   Haier_Make,
+  Hantarex_Make,
   HarmanKardon_Make,
   Hauppauge_Make,
   Hitachi_Make,
@@ -61,6 +63,8 @@ enum PIRMakeName{
   Kaon_Make,
   Kathrein_Make,
   Kenwood_Make,
+  Keymat_Make,
+  Konka_Make,
   Lexuz_Make,
   LG_Make,
   Lifetec_Make,
@@ -119,6 +123,7 @@ enum PIRMakeName{
   Vizio_Make,
   WD_Make,
   Westinghouse_Make,
+  Wiwa_Make,
   Xcruiser_Make,
   Yamaha_Make,
   Zenith_Make
